explain
*******



ShapExplainer
=============
.. autoclass:: ai4water.postprocessing.explain.ShapExplainer
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__


LimeMLExplainer
===============
.. autoclass:: ai4water.postprocessing.explain.LimeExplainer
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__


PermutationImportance
=====================
.. autoclass:: ai4water.postprocessing.explain.PermutationImportance
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__


PartialDependencePlot
=====================
.. autoclass:: ai4water.postprocessing.explain.PartialDependencePlot
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__


explain_model
=============
.. automodule:: ai4water.postprocessing.explain.explain_model
   :show-inheritance:

explain_model_with_lime
==========================
.. automodule:: ai4water.postprocessing.explain.explain_model_with_lime
   :show-inheritance:

explain_model_with_shap
=======================
.. automodule:: ai4water.postprocessing.explain.explain_model_with_shap
   :show-inheritance:
